@@ -8,6 +8,7 @@ from bigeye_cli.functions import cli_client_factory
 from bigeye_cli import global_options
 from bigeye_cli.bigconfig import bigconfig_options
 from bigeye_cli.model.github_report import GitHubReport
+from bigeye_sdk.bigconfig_validation.big_config_reports import all_reports
 from bigeye_sdk.controller.metric_controller import MetricController
 from bigeye_sdk.controller.metric_suite_controller import MetricSuiteController
 from bigeye_sdk.generated.com.bigeye.models.generated import MetricInfoList
@@ -63,17 +64,20 @@ def plan(
             apply=False,
         )
     else:
+        if no_queue:
+            log.warning(
+                "The --no_queue flag is deprecated. The option will be ignored now and removed in a later version."
+            )
         report = mc.execute_bigconfig(
             input_path=input_path,
             output_path=output_path,
             apply=False,
             recursive=recursive,
-            no_queue=no_queue,
             strict_mode=strict_mode,
         )
     if cicd:
         gh_report = GitHubReport(github_token=os.environ["GITHUB_TOKEN"])
-        gh_report.publish_bigconfig_plan(plan=report)
+        gh_report.publish_bigconfig(console_report=report, file_reports=all_reports())
 
 
 @app.command()
@@ -112,11 +116,14 @@ def apply(
             apply=True,
         )
     else:
+        if no_queue:
+            log.warning(
+                "The --no_queue flag is deprecated. The option will be ignored now and removed in a later version."
+            )
         mc.execute_bigconfig(
             input_path=input_path,
             output_path=output_path,
             apply=True,
-            no_queue=no_queue,
             recursive=recursive,
             strict_mode=strict_mode,
             auto_approve=auto_approve,
