@@ -870,14 +870,31 @@ def delete_template(
         bigeye_conf: str = global_options.bigeye_conf,
         config_file: str = global_options.config_file,
         workspace: str = global_options.workspace,
-        template_id: int = typer.Option(
-            ..., "--template_id", "-tid", help="The ID of the metric template"
+        template_id: Optional[int] = typer.Option(
+            None, "--template_id", "-tid", help="The ID of the metric template"
         ),
+        template_name: Optional[str] = typer.Option(
+            None, "--name", "-tn", help="The name of the metric template"
+        )
 ):
     """Delete a template."""
+    if not template_name and not template_id:
+        raise MissingArgumentException("Template ID or name must be provided.")
+
     client = cli_client_factory(bigeye_conf, config_file, workspace)
-    client.delete_metric_template(template_id=template_id)
-    log.info(f"Template ID {template_id} deleted.")
+
+    if template_id:
+        client.delete_metric_template(template_id=template_id)
+        log.info(f"Template ID {template_id} deleted.")
+    else:
+        try:
+            template_id = [
+                t.id for t in client.get_all_metric_templates() if t.name.lower() == template_name.lower()
+            ][0]
+            client.delete_metric_template(template_id=template_id)
+            log.info(f"Template {template_name} deleted.")
+        except IndexError:
+            log.info(f"No template found with the name {template_name}. Nothing to do.")
 
 
 @app.command()
@@ -926,16 +943,15 @@ def upsert_virtual_table(
             f"else the virtual table will be created."
         )
 
-
     table: Table = next(
-            (
-                vt.table
-                for vt in client.get_all_virtual_tables()
-                if vt.table.warehouse_id == source.id
-                   and vt.table.name == virtual_table_name
-            ),
-            None,
-        )
+        (
+            vt.table
+            for vt in client.get_all_virtual_tables()
+            if vt.table.warehouse_id == source.id
+               and vt.table.name == virtual_table_name
+        ),
+        None,
+    )
 
     if table:
         log.info(f"Update {table.name} in warehouse {source.name}")
