@@ -2,6 +2,7 @@ from typing import Optional, List
 
 import typer
 
+from bigeye_cli import global_options
 from bigeye_cli.functions import cli_client_factory, write_issue_info
 from bigeye_sdk.log import get_logger
 
@@ -16,11 +17,9 @@ File should contain commands that impact issues.
 
 @app.command()
 def get_issues(
-        bigeye_conf: str = typer.Option(
-            None
-            , "--bigeye_conf"
-            , "-b"
-            , help="Bigeye Basic Auth Configuration File"),
+        bigeye_conf: str = global_options.bigeye_conf,
+        config_file: str = global_options.config_file,
+        workspace: str = global_options.workspace,
         warehouse_ids: Optional[List[int]] = typer.Option(
             None
             , "--warehouse_id"
@@ -54,10 +53,10 @@ def get_issues(
             , help="File to write the failed metric configurations to.")
 ):
     """Gets issues and writes info to files."""
-    client = cli_client_factory(bigeye_conf)
+    client = cli_client_factory(bigeye_conf, config_file, workspace)
 
     issues = client.get_issues(warehouse_ids=warehouse_ids,
-                               schemas=schemas,
+                               schema_names=schemas,
                                metric_ids=metric_ids,
                                collection_ids=collection_ids,
                                issue_ids=issue_ids)
@@ -67,11 +66,9 @@ def get_issues(
 
 @app.command()
 def update_issue(
-        bigeye_conf: str = typer.Option(
-            None
-            , "--bigeye_conf"
-            , "-b"
-            , help="Bigeye Basic Auth Configuration File"),
+        bigeye_conf: str = global_options.bigeye_conf,
+        config_file: str = global_options.config_file,
+        workspace: str = global_options.workspace,
         issue_id: int = typer.Option(
             ...
             , "--issue_id"
@@ -99,7 +96,7 @@ def update_issue(
             , help="Used to train Bigeye when closing an issue. Options are TRUE_POSITIVE, FALSE_POSITIVE, EXPECTED.")
 ):
     """Updates an issue in Bigeye and returns the Issue object from the protobuff."""
-    client = cli_client_factory(bigeye_conf)
+    client = cli_client_factory(bigeye_conf, config_file, workspace)
 
     client.update_issue(issue_id=issue_id,
                         issue_status=issue_status,
