@@ -1,11 +1,13 @@
 import os
 from dataclasses import dataclass
+from typing import List
 
 from github import Github
 from github.Issue import Issue
 from github.PullRequest import PullRequest
 from github.Repository import Repository
 
+from bigeye_sdk.bigconfig_validation.big_config_reports import BIGCONFIG_REPORT
 from bigeye_sdk.log import get_logger
 from bigeye_sdk.generated.com.bigeye.models.generated import DeltaInfo
 from bigeye_cli.model.vendor_report import (
@@ -31,7 +33,7 @@ class GitHubReport(VendorReport):
         self.pr = self.repo.get_pull(int(os.environ["PR_NUMBER"]))
 
     def publish(
-        self, base_url: str, source_table_name: str, target_table_name: str, di: DeltaInfo
+            self, base_url: str, source_table_name: str, target_table_name: str, di: DeltaInfo
     ) -> int:
 
         dti = di.comparison_target_infos[0]
@@ -43,9 +45,6 @@ class GitHubReport(VendorReport):
             log.error("The process will exit as failed.")
             report = _format_report(url, source_table_name, target_table_name, dti)
             body = f"Bigeye Delta failure for PR: {self.pr.title}\n\n{report}"
-            # self.issue = self.repo.create_issue(
-            #     title=failure_title, body=report, assignee=self.pr.user, labels=["bug"]
-            # )
             self.pr.create_issue_comment(body=body)
             return 1
         elif dti.schema_match is False:
@@ -62,7 +61,7 @@ class GitHubReport(VendorReport):
             return 0
 
     def publish_group_bys(
-        self, base_url: str, source_table_name: str, target_table_name: str, di: DeltaInfo
+            self, base_url: str, source_table_name: str, target_table_name: str, di: DeltaInfo
     ):
         dti = di.comparison_target_infos[0]
         group_bys = di.delta.comparison_table_configurations[0].group_bys
@@ -70,5 +69,18 @@ class GitHubReport(VendorReport):
         report = _format_group_report(url, source_table_name, target_table_name, dti, group_bys)
         self.pr.create_issue_comment(body=report)
 
-    def publish_bigconfig_plan(self, plan: str):
-        self.pr.create_issue_comment(body=plan)
+    def publish_bigconfig(self, console_report: str, file_reports: List[BIGCONFIG_REPORT]):
+        self.pr.create_issue_comment(body=console_report)
+        full_report = []
+        for report in file_reports:
+            cleansed_source_name = report.source_name.replace("/", "").replace(" ", "_")
+            title = f"{cleansed_source_name}"
+            source_report = (f"<details>"
+                             f"  <summary><b>Full Plan: {title}</b></summary>"
+                             f"\n\n"
+                             f"```yaml\n"
+                             f"{report}\n"
+                             f"```\n"
+                             f"</details>")
+            full_report.append(source_report)
+        self.pr.create_issue_comment(body="\n".join(full_report))
