@@ -1,6 +1,7 @@
 import abc
 from typing import List
 
+from bigeye_sdk.bigconfig_validation.big_config_reports import BIGCONFIG_REPORT
 from bigeye_sdk.generated.com.bigeye.models.generated import ComparisonMetricInfo, ComparisonMetricStatus, \
     PredefinedMetricName, DeltaTargetInfo, ColumnNamePair, Delta, DeltaInfo
 
@@ -103,7 +104,7 @@ class VendorReport(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def publish_bigconfig_plan(self, plan: str):
+    def publish_bigconfig(self, console_report: str, file_reports: List[BIGCONFIG_REPORT]):
         pass
 
 # This generated Markdown tables similar to the dimensional view in Bigeye.
