@@ -20,7 +20,7 @@ from bigeye_sdk.generated.com.bigeye.models.generated import (
     Workspace,
     Group,
     RoleOperation,
-    Group,
+    Group, BulkChangeGroupGrantsResponse,
 )
 
 log = get_logger(__file__)
@@ -486,7 +486,7 @@ def edit_group_access(
             "Edit",
             "--access-level",
             "-access",
-            help="The access this group should have to the workspaces provided. Must be either `Edit` or `Manage`",
+            help="The access this group should have to the workspaces provided. Must be `View`, `Edit`, or `Manage`",
         ),
         operation: int = typer.Option(
             RoleOperation.ROLE_OPERATION_GRANT.value,
@@ -498,9 +498,9 @@ def edit_group_access(
     """Edit the workspaces that a group can access."""
     client = cli_client_factory(bigeye_conf, config_file, workspace)
 
-    if access_level.lower() not in ["edit", "manage"]:
+    if access_level.lower() not in ["view", "edit", "manage"]:
         raise typer.BadParameter(
-            f"Invalid access level provided. Must be either `Manage` or `Edit `"
+            f"Invalid access level provided. Must be `View`, `Edit`, or `Manage`"
         )
 
     if group_id:
@@ -530,43 +530,38 @@ def edit_group_access(
     workspaces: List[Workspace] = [
         w for w in client.get_workspaces().workspaces if w.name in workspace_names
     ]
-    workspace_ids: List[int] = [w.id for w in workspaces]
-    roles = [
-        r
-        for r in client.get_roles().roles
-        if r.workspace_id in workspace_ids and r.name.lower() == access_level.lower()
-    ]
+    role = next(r for r in client.get_roles().roles
+                if r.name.lower() == access_level.lower())
+    workspace_ids = [w.id for w in workspaces]
 
     # warn user of workspace names not found
     valid_workspace_names = [w.name.lower() for w in workspaces]
     for w in workspace_names:
-        if w not in valid_workspace_names:
+        if w.lower() not in valid_workspace_names:
             log.warning(
                 f"Workspace name `{w}` could not be found and will not be added to {group_name} access."
             )
 
-    response = client.edit_group_roles(
-        group_id=group.id,
-        role_ids=[r.id for r in roles],
+    response: BulkChangeGroupGrantsResponse = client.edit_group_roles(
+        group=group,
+        role=role,
+        workspace_ids=workspace_ids,
         operation=RoleOperation(operation),
     )
 
     # warn user that some group/role pairs may have failed to update
     for failed_update in response.failed_updates:
-        failed_role = next(filter(lambda r: r.id == failed_update.id, roles), None)
         log.warning(
-            f"Group role failed to be updated. Group = {group.name}, Role = {failed_role.name}"
+            f"Group role failed to be updated. Group = {failed_update.request.group.display_name}, "
+            f"Role = {failed_update.request.role.name}, "
+            f"Workspace = {failed_update.request.workspace.display_name}"
         )
 
     # validate all successful updates
-    for succeeded_id in response.successful_ids:
-        succeeded_role = next(filter(lambda r: r.id == succeeded_id, roles), None)
-        succeeded_workspace = next(
-            filter(lambda w: w.id == succeeded_role.workspace_id, workspaces), None
-        )
+    for successful_update in response.successful_requests:
         log.info(
-            f"Group {group.name} has been updated for the {succeeded_role.name} role "
-            f"in the {succeeded_workspace.name} workspace."
+            f"Group {successful_update.group.display_name} has been updated for the {successful_update.role.name} role "
+            f"in the {successful_update.workspace.display_name} workspace."
         )
 
 
